@@ -2,6 +2,8 @@ package app
 
 import (
 	"fmt"
+	"strconv"
+
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/environment"
@@ -9,7 +11,6 @@ import (
 	"github.com/abiosoft/colima/environment/host"
 	"github.com/abiosoft/colima/environment/vm/lima"
 	log "github.com/sirupsen/logrus"
-	"strconv"
 )
 
 type App interface {
@@ -43,7 +44,7 @@ type colimaApp struct {
 }
 
 func (c colimaApp) Start(conf config.Config) error {
-	log.Println("starting", config.Profile())
+	log.Println("starting", config.Profile().DisplayName)
 
 	var containers []environment.Container
 	// runtime
@@ -83,15 +84,11 @@ func (c colimaApp) Start(conf config.Config) error {
 		return fmt.Errorf("error setting kubernetes version: %w", err)
 	}
 
-	// provision container runtimes
+	// provision and start container runtimes
 	for _, cont := range containers {
 		if err := cont.Provision(); err != nil {
 			return fmt.Errorf("error provisioning %s: %w", cont.Name(), err)
 		}
-	}
-
-	// start container runtimes
-	for _, cont := range containers {
 		if err := cont.Start(); err != nil {
 			return fmt.Errorf("error starting %s: %w", cont.Name(), err)
 		}
@@ -102,7 +99,7 @@ func (c colimaApp) Start(conf config.Config) error {
 }
 
 func (c colimaApp) Stop() error {
-	log.Println("stopping", config.Profile())
+	log.Println("stopping", config.Profile().DisplayName)
 
 	// the order for stop is:
 	//   container stop -> vm stop
@@ -137,19 +134,19 @@ func (c colimaApp) Stop() error {
 }
 
 func (c colimaApp) Delete() error {
-	y := cli.Prompt("are you sure you want to delete " + config.Profile() + " and all settings")
+	y := cli.Prompt("are you sure you want to delete " + config.Profile().DisplayName + " and all settings")
 	if !y {
 		return nil
 	}
 
-	log.Println("deleting", config.Profile())
+	log.Println("deleting", config.Profile().DisplayName)
 
 	// the order for teardown is:
 	//   container teardown -> vm teardown
 
 	// vm teardown would've sufficed but container provision
 	// may have created configurations on the host.
-	// it is essential to teardown containers as well.
+	// it is thereby necessary to teardown containers as well.
 
 	// teardown container runtimes
 	if c.guest.Running() {
@@ -181,7 +178,7 @@ func (c colimaApp) Delete() error {
 
 func (c colimaApp) SSH(args ...string) error {
 	if !c.guest.Running() {
-		return fmt.Errorf("%s not running", config.Profile())
+		return fmt.Errorf("%s not running", config.Profile().DisplayName)
 	}
 
 	return c.guest.RunInteractive(args...)
@@ -189,7 +186,7 @@ func (c colimaApp) SSH(args ...string) error {
 
 func (c colimaApp) Status() error {
 	if !c.guest.Running() {
-		return fmt.Errorf("%s is not running", config.Profile())
+		return fmt.Errorf("%s is not running", config.Profile().DisplayName)
 	}
 
 	currentRuntime, err := c.currentRuntime()
@@ -197,8 +194,9 @@ func (c colimaApp) Status() error {
 		return err
 	}
 
-	log.Println(config.Profile(), "is running")
+	log.Println(config.Profile().DisplayName, "is running")
 	log.Println("runtime:", currentRuntime)
+	log.Println("arch:", c.guest.Arch())
 
 	// kubernetes
 	if k, err := c.Kubernetes(); err == nil && k.Running() {
@@ -226,6 +224,7 @@ func (c colimaApp) Version() error {
 		}
 		fmt.Println()
 		fmt.Println("runtime:", cont.Name())
+		fmt.Println("arch:", c.guest.Arch())
 		fmt.Println(cont.Version())
 	}
 
@@ -240,7 +239,7 @@ func (c colimaApp) Version() error {
 
 func (c colimaApp) currentRuntime() (string, error) {
 	if !c.guest.Running() {
-		return "", fmt.Errorf("%s is not running", config.Profile())
+		return "", fmt.Errorf("%s is not running", config.Profile().DisplayName)
 	}
 
 	r := c.guest.Get(environment.ContainerRuntimeKey)
