@@ -2,25 +2,43 @@ package config
 
 import (
 	"fmt"
-	"github.com/abiosoft/colima/util/yamlutil"
-	"gopkg.in/yaml.v3"
 	"log"
 	"net"
 	"os"
 	"path/filepath"
+	"sync"
+
+	"github.com/abiosoft/colima/util/yamlutil"
+	"gopkg.in/yaml.v3"
 )
 
 const AppName = "colima"
 
-var profile = AppName
+var profile = ProfileInfo{ID: AppName, DisplayName: AppName}
 
 // SetProfile sets the profile name for the application.
 // This is an avenue to test Colima without breaking an existing stable setup.
 // Not perfect, but good enough for testing.
-func SetProfile(p string) { profile = p }
+func SetProfile(profileName string) {
+	switch profileName {
+	case "", AppName, "default":
+		return
+	}
+
+	// if custom profile is specified,
+	// use a prefix to prevent possible name clashes
+	profile.ID = "colima-" + profileName
+	profile.DisplayName = "colima [profile=" + profileName + "]"
+}
 
 // Profile returns the current application profile.
-func Profile() string { ensureInit(); return profile }
+func Profile() ProfileInfo { return profile }
+
+// ProfileInfo is information about the colima profile.
+type ProfileInfo struct {
+	ID          string
+	DisplayName string
+}
 
 // VersionInfo is the application version info.
 type VersionInfo struct {
@@ -28,61 +46,71 @@ type VersionInfo struct {
 	Revision string
 }
 
-func AppVersion() VersionInfo {
-	ensureInit()
-	return VersionInfo{Version: appVersion, Revision: revision}
-}
+func AppVersion() VersionInfo { return VersionInfo{Version: appVersion, Revision: revision} }
 
 var (
 	appVersion = "development"
 	revision   = "unknown"
+)
 
-	configDir string
-	cacheDir  string
+// requiredDir is a directory that must exist on the filesystem
+type requiredDir struct {
+	once sync.Once
+	// dir is a func to enable deferring the value of the directory
+	// until execution time.
+	// if dir() returns an error, a fatal error is triggered.
+	dir func() (string, error)
+}
+
+// Dir returns the directory path.
+// It ensures the directory is created on the filesystem by calling
+// `mkdir` prior to returning the directory path.
+func (r *requiredDir) Dir() string {
+	dir, err := r.dir()
+	if err != nil {
+		log.Fatal(fmt.Errorf("cannot fetch required directory: %w", err))
+	}
+
+	r.once.Do(func() {
+		if err := os.MkdirAll(dir, 0755); err != nil {
+			log.Fatal(fmt.Errorf("cannot make required directory: %w", err))
+		}
+	})
+
+	return dir
+}
+
+var (
+	configDir requiredDir = requiredDir{
+		dir: func() (string, error) {
+			dir, err := os.UserHomeDir()
+			if err != nil {
+				return "", err
+			}
+			return filepath.Join(dir, "."+profile.ID), nil
+		},
+	}
+
+	cacheDir requiredDir = requiredDir{
+		dir: func() (string, error) {
+			dir, err := os.UserCacheDir()
+			if err != nil {
+				return "", err
+			}
+			return filepath.Join(dir, profile.ID), nil
+		},
+	}
 )
 
 // Dir returns the configuration directory.
-func Dir() string { ensureInit(); return configDir }
+func Dir() string { return configDir.Dir() }
 
 // CacheDir returns the cache directory.
-func CacheDir() string { ensureInit(); return cacheDir }
-
-var initDone = false
-
-func ensureInit() {
-	if initDone {
-		return
-	}
-
-	{
-		// prepare config directory
-		dir, err := os.UserHomeDir()
-		if err != nil {
-			log.Fatal(fmt.Errorf("cannot fetch user config directory: %w", err))
-		}
-		configDir = filepath.Join(dir, "."+profile)
-		if err := os.MkdirAll(configDir, 0755); err != nil {
-			log.Fatal(fmt.Errorf("cannot create config directory: %w", err))
-		}
-	}
-
-	{
-		// prepare cache directory
-		dir, err := os.UserCacheDir()
-		if err != nil {
-			log.Fatal(fmt.Errorf("cannot fetch user config directory: %w", err))
-		}
-		cacheDir = filepath.Join(dir, profile)
-		if err := os.MkdirAll(cacheDir, 0755); err != nil {
-			log.Fatal(fmt.Errorf("cannot create cache directory: %w", err))
-		}
-	}
-	initDone = true
-}
+func CacheDir() string { return cacheDir.Dir() }
 
 const configFileName = "colima.yaml"
 
-func configFile() string { ensureInit(); return filepath.Join(configDir, configFileName) }
+func configFile() string { return filepath.Join(configDir.Dir(), configFileName) }
 
 // Save saves the config.
 func Save(c Config) error {
@@ -112,8 +140,8 @@ func Load() (Config, error) {
 
 // Teardown deletes the config.
 func Teardown() error {
-	if _, err := os.Stat(configDir); err == nil {
-		return os.RemoveAll(configDir)
+	if _, err := os.Stat(configDir.Dir()); err == nil {
+		return os.RemoveAll(configDir.Dir())
 	}
 	return nil
 }
@@ -128,6 +156,9 @@ type Config struct {
 
 	// Kubernetes sets if kubernetes should be enabled.
 	Kubernetes Kubernetes `yaml:"kubernetes"`
+
+	// Network address to forward VM ports to.
+	PortInterface net.IP `yaml:"port_interface"`
 }
 
 // Kubernetes is kubernetes configuration
@@ -138,12 +169,14 @@ type Kubernetes struct {
 
 // VM is virtual machine configuration.
 type VM struct {
-	CPU    int `yaml:"cpu"`
-	Disk   int `yaml:"disk"`
-	Memory int `yaml:"memory"`
+	CPU    int    `yaml:"cpu"`
+	Disk   int    `yaml:"disk"`
+	Memory int    `yaml:"memory"`
+	Arch   string `yaml:"arch"`
 
 	// auto generated
-	SSHPort int `yaml:"-"`
+	SSHPort      int  `yaml:"-"`
+	ForwardAgent bool `yaml:"forward_agent"`
 
 	// volume mounts
 	Mounts []string `yaml:"mounts"`
