@@ -1,6 +1,8 @@
 package containerd
 
 import (
+	"time"
+
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/environment"
 )
@@ -43,10 +45,17 @@ func (c containerdRuntime) Provision() error {
 
 func (c containerdRuntime) Start() error {
 	a := c.Init()
+
 	a.Stage("starting")
 	a.Add(func() error {
 		return c.guest.Run("sudo", "service", "containerd", "start")
 	})
+
+	// service startup takes few seconds, retry at most 10 times before giving up.
+	a.Retry("waiting for startup to complete", time.Second*5, 10, func() error {
+		return c.guest.RunQuiet("sudo", "nerdctl", "info")
+	})
+
 	return a.Exec()
 }
 
