@@ -1,27 +1,40 @@
 package lima
 
 import (
-	_ "embed"
+	"bufio"
+	"bytes"
 	"encoding/json"
 	"fmt"
+	"os"
+	"path/filepath"
+	"strconv"
+	"strings"
+	"time"
+
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/yamlutil"
-	"os"
-	"path/filepath"
-	"strconv"
-	"time"
+	"github.com/sirupsen/logrus"
 )
 
 // New creates a new virtual machine.
 func New(host environment.HostActions) environment.VM {
-	env := limaInstanceEnvVar + "=" + config.Profile()
+	env := limaInstanceEnvVar + "=" + config.Profile().ID
+
+	home, err := limaHome()
+	if err != nil {
+		err = fmt.Errorf("error detecting Lima config directory: %w", err)
+		logrus.Warnln(err)
+		logrus.Warnln("falling back to default '$HOME/.lima'")
+		home = filepath.Join(util.HomeDir(), ".lima")
+	}
 
 	// consider making this truly flexible to support other VMs
 	return &limaVM{
 		host:         host.WithEnv(env),
+		home:         home,
 		CommandChain: cli.New("vm"),
 	}
 }
@@ -32,9 +45,30 @@ const (
 	limactl            = "limactl"
 )
 
-func limaConfDir() string {
-	home := util.HomeDir()
-	return filepath.Join(home, ".lima", config.Profile())
+func limaHome() (string, error) {
+	var buf bytes.Buffer
+	cmd := cli.Command("limactl", "info")
+	cmd.Stdout = &buf
+
+	if err := cmd.Run(); err != nil {
+		return "", fmt.Errorf("error retrieving lima info: %w", err)
+	}
+
+	var resp struct {
+		LimaHome string `json:"limaHome"`
+	}
+	if err := json.NewDecoder(&buf).Decode(&resp); err != nil {
+		return "", fmt.Errorf("error decoding json for lima info: %w", err)
+	}
+	if resp.LimaHome == "" {
+		return "", fmt.Errorf("error retrieving lima info, ensure lima version is >0.7.4")
+	}
+
+	return resp.LimaHome, nil
+}
+
+func (l limaVM) limaConfDir() string {
+	return filepath.Join(l.home, config.Profile().ID)
 }
 
 var _ environment.VM = (*limaVM)(nil)
@@ -45,6 +79,9 @@ type limaVM struct {
 
 	// keep config in case of restart
 	conf config.Config
+
+	// lima config directory
+	home string
 }
 
 func (l limaVM) Dependencies() []string {
@@ -62,7 +99,7 @@ func (l *limaVM) Start(conf config.Config) error {
 
 	a.Stage("creating and starting")
 
-	configFile := config.Profile() + ".yaml"
+	configFile := config.Profile().ID + ".yaml"
 
 	a.Add(func() error {
 		limaConf, err := newConf(conf)
@@ -98,7 +135,7 @@ func (l limaVM) resume(conf config.Config) error {
 		return nil
 	}
 
-	configFile := filepath.Join(limaConfDir(), "lima.yaml")
+	configFile := filepath.Join(l.limaConfDir(), "lima.yaml")
 
 	a.Add(func() error {
 		limaConf, err := newConf(conf)
@@ -110,7 +147,7 @@ func (l limaVM) resume(conf config.Config) error {
 
 	a.Stage("starting")
 	a.Add(func() error {
-		return l.host.Run(limactl, "start", config.Profile())
+		return l.host.Run(limactl, "start", config.Profile().ID)
 	})
 
 	l.applyDNS(a, conf)
@@ -160,7 +197,7 @@ func (l limaVM) Stop() error {
 	a.Stage("stopping")
 
 	a.Add(func() error {
-		return l.host.Run(limactl, "stop", config.Profile())
+		return l.host.Run(limactl, "stop", config.Profile().ID)
 	})
 
 	return a.Exec()
@@ -168,17 +205,11 @@ func (l limaVM) Stop() error {
 
 func (l limaVM) Teardown() error {
 	a := l.Init()
-	if l.Running() {
-		// lima needs to be stopped before it can be deleted.
-		if err := l.Stop(); err != nil {
-			return err
-		}
-	}
 
 	a.Stage("deleting")
 
 	a.Add(func() error {
-		return l.host.Run(limactl, "delete", config.Profile())
+		return l.host.Run(limactl, "delete", "--force", config.Profile().ID)
 	})
 
 	return a.Exec()
@@ -266,7 +297,7 @@ func (l limaVM) Env(s string) (string, error) {
 }
 
 func (l limaVM) Created() bool {
-	stat, err := os.Stat(limaConfDir())
+	stat, err := os.Stat(l.limaConfDir())
 	return err == nil && stat.IsDir()
 }
 
@@ -314,3 +345,54 @@ func (l limaVM) Set(key, value string) error {
 func (l limaVM) User() (string, error) {
 	return l.RunOutput("whoami")
 }
+
+func (l limaVM) Arch() environment.Arch {
+	a, _ := l.RunOutput("uname", "-m")
+	return environment.Arch(a)
+}
+
+// InstanceInfo is the information about a Lima instance
+type InstanceInfo struct {
+	Name   string `json:"name,omitempty"`
+	Status string `json:"status,omitempty"`
+	Arch   string `json:"arch,omitempty"`
+	CPU    int    `json:"cpus,omitempty"`
+	Memory int64  `json:"memory,omitempty"`
+	Disk   int64  `json:"disk,omitempty"`
+}
+
+// Instances returns Lima instances created by colima.
+func Instances() ([]InstanceInfo, error) {
+	var buf bytes.Buffer
+	cmd := cli.Command("limactl", "list", "--json")
+	cmd.Stdout = &buf
+
+	if err := cmd.Run(); err != nil {
+		return nil, fmt.Errorf("error retrieving instances: %w", err)
+	}
+
+	var instances []InstanceInfo
+	scanner := bufio.NewScanner(&buf)
+	for scanner.Scan() {
+		var i InstanceInfo
+		line := scanner.Bytes()
+		if err := json.Unmarshal(line, &i); err != nil {
+			return nil, fmt.Errorf("error retrieving instances: %w", err)
+		}
+
+		// limit to colima instances
+		if !strings.HasPrefix(i.Name, "colima") {
+			continue
+		}
+
+		// rename to local friendly names
+		if i.Name == "colima" {
+			i.Name = "default"
+		}
+		i.Name = strings.TrimPrefix(i.Name, "colima-")
+
+		instances = append(instances, i)
+	}
+
+	return instances, nil
+}
