@@ -2,28 +2,31 @@ package lima
 
 import (
 	"fmt"
-	"github.com/abiosoft/colima/config"
-	"github.com/abiosoft/colima/environment/container/containerd"
-	"github.com/abiosoft/colima/util"
 	"net"
 	"os"
 	"path/filepath"
 	"strings"
+
+	"github.com/abiosoft/colima/config"
+	"github.com/abiosoft/colima/environment"
+	"github.com/abiosoft/colima/environment/container/docker"
+	"github.com/abiosoft/colima/util"
 )
 
 func newConf(conf config.Config) (l Config, err error) {
-	l.Arch = "default"
+	l.Arch = environment.Arch(conf.VM.Arch).Value()
 
 	l.Images = append(l.Images,
-		File{Arch: X8664, Location: "https://cloud-images.ubuntu.com/impish/current/impish-server-cloudimg-amd64.img"},
-		File{Arch: AARCH64, Location: "https://cloud-images.ubuntu.com/impish/current/impish-server-cloudimg-arm64.img"})
+		File{Arch: environment.AARCH64, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.1/alpine-lima-clm-3.14.3-aarch64.iso", Digest: "sha512:f1a8d3f0029e21ad6735f614e21cac51704d8c903fdd547fb9f0162f63fae2dbbac2d260a868952a890e6653ac3e151e9cfe0e98bc2822e4667bf0eed82812b5"},
+		File{Arch: environment.X8664, Location: "https://github.com/abiosoft/alpine-lima/releases/download/colima-v0.3.1/alpine-lima-clm-3.14.3-x86_64.iso", Digest: "sha512:e805f264df9410533425526c0397b00d4de5b36b2b3a7af690bad8d8ef8d1f67ca66e56000ac0dd8c6719cacb03cb5d8b864e45b5e91d6957dfe284859d2c915"},
+	)
 
 	l.CPUs = conf.VM.CPU
 	l.Memory = fmt.Sprintf("%dGiB", conf.VM.Memory)
 	l.Disk = fmt.Sprintf("%dGiB", conf.VM.Disk)
 
-	l.SSH = SSH{LocalPort: conf.VM.SSHPort, LoadDotSSHPubKeys: false}
-	l.Containerd = Containerd{System: conf.Runtime == containerd.Name, User: false}
+	l.SSH = SSH{LocalPort: conf.VM.SSHPort, LoadDotSSHPubKeys: false, ForwardAgent: conf.VM.ForwardAgent}
+	l.Containerd = Containerd{System: false, User: false}
 	l.Firmware.LegacyBIOS = false
 
 	l.DNS = conf.VM.DNS
@@ -34,10 +37,34 @@ func newConf(conf config.Config) (l Config, err error) {
 		l.Env[k] = v
 	}
 
+	// port forwarding
+	{
+		// docker socket
+		if conf.Runtime == docker.Name {
+			l.PortForwards = append(l.PortForwards,
+				PortForward{
+					GuestSocket: "/var/run/docker.sock",
+					HostSocket:  docker.HostSocketFile(),
+					Proto:       TCP,
+				})
+		}
+
+		// handle port forwarding to allow listening on 0.0.0.0
+		l.PortForwards = append(l.PortForwards,
+			PortForward{
+				GuestIP:        net.ParseIP("127.0.0.1"),
+				GuestPortRange: [2]int{1, 65535},
+				HostIP:         conf.PortInterface,
+				HostPortRange:  [2]int{1, 65535},
+				Proto:          TCP,
+			},
+		)
+	}
+
 	if len(conf.VM.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
-			Mount{Location: "~", Writable: false},
-			Mount{Location: filepath.Join("/tmp", config.Profile()), Writable: true},
+			Mount{Location: "~", Writable: true},
+			Mount{Location: filepath.Join("/tmp", config.Profile().ID), Writable: true},
 		)
 	} else {
 		// overlapping mounts are problematic in Lima https://github.com/lima-vm/lima/issues/302
@@ -71,7 +98,7 @@ func newConf(conf config.Config) (l Config, err error) {
 
 // Config is lima config. Code copied from lima and modified.
 type Config struct {
-	Arch            Arch              `yaml:"arch,omitempty"`
+	Arch            environment.Arch  `yaml:"arch,omitempty"`
 	Images          []File            `yaml:"images"`
 	CPUs            int               `yaml:"cpus,omitempty"`
 	Memory          string            `yaml:"memory,omitempty"`
@@ -83,18 +110,13 @@ type Config struct {
 	DNS             []net.IP          `yaml:"-"` // will be handled manually by colima
 	Firmware        Firmware          `yaml:"firmware"`
 	UseHostResolver bool              `yaml:"useHostResolver"`
+	PortForwards    []PortForward     `yaml:"portForwards,omitempty"`
 }
 
-type Arch = string
-
-const (
-	X8664   Arch = "x86_64"
-	AARCH64 Arch = "aarch64"
-)
-
 type File struct {
-	Location string `yaml:"location"` // REQUIRED
-	Arch     Arch   `yaml:"arch,omitempty"`
+	Location string           `yaml:"location"` // REQUIRED
+	Arch     environment.Arch `yaml:"arch,omitempty"`
+	Digest   string           `yaml:"digest,omitempty"`
 }
 
 type Mount struct {
@@ -107,6 +129,7 @@ type SSH struct {
 	// LoadDotSSHPubKeys loads ~/.ssh/*.pub in addition to $LIMA_HOME/_config/user.pub .
 	// Default: true
 	LoadDotSSHPubKeys bool `yaml:"loadDotSSHPubKeys"`
+	ForwardAgent      bool `yaml:"forwardAgent,omitempty"` // default: false
 }
 
 type Containerd struct {
@@ -120,6 +143,24 @@ type Firmware struct {
 	LegacyBIOS bool `yaml:"legacyBIOS"`
 }
 
+type Proto = string
+
+const (
+	TCP Proto = "tcp"
+)
+
+type PortForward struct {
+	GuestIP        net.IP `yaml:"guestIP,omitempty" json:"guestIP,omitempty"`
+	GuestPort      int    `yaml:"guestPort,omitempty" json:"guestPort,omitempty"`
+	GuestPortRange [2]int `yaml:"guestPortRange,omitempty" json:"guestPortRange,omitempty"`
+	GuestSocket    string `yaml:"guestSocket,omitempty" json:"guestSocket,omitempty"`
+	HostIP         net.IP `yaml:"hostIP,omitempty" json:"hostIP,omitempty"`
+	HostPort       int    `yaml:"hostPort,omitempty" json:"hostPort,omitempty"`
+	HostPortRange  [2]int `yaml:"hostPortRange,omitempty" json:"hostPortRange,omitempty"`
+	HostSocket     string `yaml:"hostSocket,omitempty" json:"hostSocket,omitempty"`
+	Proto          Proto  `yaml:"proto,omitempty" json:"proto,omitempty"`
+	Ignore         bool   `yaml:"ignore,omitempty" json:"ignore,omitempty"`
+}
 type volumeMount string
 
 func (v volumeMount) Writable() bool {
@@ -140,7 +181,7 @@ func (v volumeMount) Path() (string, error) {
 		return "", fmt.Errorf("relative paths not supported for mount '%s'", string(v))
 	}
 
-	return str, nil
+	return strings.TrimSuffix(str, "/") + "/", nil
 }
 
 func checkOverlappingMounts(mounts []string) error {
